hash

package
v0.0.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Feb 6, 2022 License: MIT Imports: 8 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Hash

func Hash(hash string)

check for match for favicon icon with user supplied favicon hash.

func Url

func Url(url string)

compute the md5sum for the user supplied favicon url and use the result to find the match for known framework based on already pre-computed hashes

Types

This section is empty.

Jump to